@@ -32,10 +32,13 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
     def _type_hints(self):
         return self._tabledata.dp_extractor.column_type_hints
 
-    def __init__(self, tabledata):
+    def __init__(self, tabledata: TableData) -> None:
         self._tabledata = tabledata
 
-    def validate(self):
+    def validate(self) -> None:
+        if not self._tabledata.table_name:
+            raise ValueError("table_name must not be empty")
+
         self._validate_table_name(self._tabledata.table_name)
         self._validate_headers()
 
@@ -50,7 +53,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         :rtype: tabledata.TableData
         """
 
-        logger.debug("normalize: {}".format(type(self).__name__))
+        logger.debug(f"normalize: {type(self).__name__}")
 
         normalize_headers = self._normalize_headers()
 
@@ -66,7 +69,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
     @abc.abstractmethod
     def _preprocess_table_name(self) -> str:
         """
-        Always called before table name validation.
+        This method is always called before table name validation.
         You must return preprocessed table name.
         """
 
@@ -86,7 +89,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
     def _normalize_table_name(self, table_name: str) -> str:
         """
         Must return a valid table name.
-        The table name must be a valid name with
+        The table name must be considered to be a valid name by
         :py:meth:`~._validate_table_name` method.
 
         This method called when :py:meth:`~._validate_table_name` method raise
@@ -100,7 +103,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
     @abc.abstractmethod
     def _preprocess_header(self, col_idx: int, header: str) -> str:
         """
-        Always called before a header validation.
+        This method is always called before a header validation.
         You must return preprocessed header.
         """
 
@@ -110,7 +113,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         No operation.
 
         This method called for each table header. Override this method
-        in subclass if you want to detect invalid table header element.
+        in a subclass if you want to detect invalid table header elements.
         Raise :py:class:`~.InvalidHeaderNameError` if an invalid
         header element found.
 
@@ -134,7 +137,7 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
         """
 
     def _normalize_rows(self, normalize_headers: Sequence[str]) -> List:
-        return self._tabledata.rows
+        return self._tabledata.rows  # type: ignore
 
     def _validate_headers(self) -> None:
         for header in self._tabledata.headers:
@@ -172,6 +175,9 @@ class AbstractTableDataNormalizer(TableDataNormalizerInterface):
 
 class TableDataNormalizer(AbstractTableDataNormalizer):
     def _preprocess_table_name(self) -> str:
+        if not self._tabledata.table_name:
+            return ""
+
         return self._tabledata.table_name
 
     def _validate_table_name(self, table_name: str) -> None:
